![CogniChem Logo](https://cognichem.com/images/cc-logo-color.svg)
# CogniChem Python Client

## Installation

### From PyPI

```
$ pip install cognichem-client
```

### From source

```
$ git clone https://github.com/cognitive-chemistry-labs/cognichem-client-python
$ cd cognichem-client-python
$ pip install .
```

## Usage

View our [example](examples/) notebooks for more information.
